@@ -38,13 +38,14 @@ class CloudPublisher(GoogleCloudPilotAPI):
             topic=topic_path,
         )
 
-    async def list_topics(self, prefix: str = '', project_id: str = None) -> AsyncIterator[Topic]:
+    async def list_topics(self, prefix: str = '', suffix: str = '', project_id: str = None) -> AsyncIterator[Topic]:
         project_path = self._project_path(project_id=project_id)
         topics = self.client.list_topics(
             project=project_path,
         )
         for topic in topics:
-            if topic.name.split('/topics/')[-1].startswith(prefix):
+            name = topic.name.split('/topics/')[-1]
+            if name.startswith(prefix) and name.endswith(suffix):
                 yield topic
 
     async def publish(
@@ -83,12 +84,18 @@ class CloudSubscriber(GoogleCloudPilotAPI):
     _service_name = 'Cloud Pub/Sub'
     _google_managed_service = True
 
-    async def list_subscriptions(self, prefix: str = '', project_id: str = None) -> AsyncIterator[Subscription]:
+    async def list_subscriptions(
+            self,
+            prefix: str = '',
+            suffix: str = '',
+            project_id: str = None,
+    ) -> AsyncIterator[Subscription]:
         all_subscriptions = self.client.list_subscriptions(
             project=f'projects/{project_id or self.project_id}',
         )
         for subscription in all_subscriptions:
-            if subscription.name.split('/subscriptions/')[-1].startswith(prefix):
+            name = subscription.name.split('/subscriptions/')[-1]
+            if name.startswith(prefix) and name.endswith(suffix):
                 yield subscription
 
     async def get_subscription(self, subscription_id: str, project_id: str = None) -> Subscription:
@@ -161,6 +168,70 @@ class CloudSubscriber(GoogleCloudPilotAPI):
                 raise
             return await self.get_subscription(subscription_id=subscription_id, project_id=project_id)
 
+    async def update_subscription(
+            self,
+            topic_id: str,
+            subscription_id: str,
+            project_id: str = None,
+            push_to_url: str = None,
+            use_oidc_auth: bool = False,
+    ) -> Subscription:
+        topic_path = self.client.topic_path(
+            project=project_id or self.project_id,
+            topic=topic_id,
+        )
+        subscription_path = self.client.subscription_path(
+            project=project_id or self.project_id,
+            subscription=subscription_id,
+        )
+
+        push_config = None
+        if push_to_url:
+            push_config = PushConfig(
+                push_endpoint=push_to_url,
+                **(self.get_oidc_token(audience=push_to_url) if use_oidc_auth else {}),
+            )
+
+        subscription = Subscription(
+            name=subscription_path,
+            topic=topic_path,
+            push_config=push_config,
+        )
+
+        update_mask = {"paths": {"push_config"}}
+
+        return self.client.update_subscription(
+            request={"subscription": subscription, "update_mask": update_mask}
+        )
+
+    async def create_or_update_subscription(
+            self,
+            topic_id: str,
+            subscription_id: str,
+            project_id: str = None,
+            auto_create_topic: bool = True,
+            push_to_url: str = None,
+            use_oidc_auth: bool = False,
+    ) -> Subscription:
+        try:
+            return await self.create_subscription(
+                topic_id=topic_id,
+                subscription_id=subscription_id,
+                project_id=project_id,
+                exists_ok=False,
+                auto_create_topic=auto_create_topic,
+                push_to_url=push_to_url,
+                use_oidc_auth=use_oidc_auth,
+            )
+        except AlreadyExists:
+            return await self.update_subscription(
+                topic_id=topic_id,
+                subscription_id=subscription_id,
+                project_id=project_id,
+                push_to_url=push_to_url,
+                use_oidc_auth=use_oidc_auth,
+            )
+
     async def subscribe(self, topic_id: str, subscription_id: str, callback: Callable, project_id: str = None):
         await self.create_subscription(
             topic_id=topic_id,
